@@ -29,7 +29,7 @@
 #ifndef _CONF_H_
 #define _CONF_H_
 
-#define VERSION "9.2.0"
+#define VERSION "9.3.0"
 
 /*
  * Defines how many times should we try detecting the interface with the default route (in seconds).
@@ -51,15 +51,18 @@
 #define DEFAULT_DAEMON 1
 #define DEFAULT_DEBUGLEVEL 1
 #define DEFAULT_MAXCLIENTS 250
+#define DEFAULT_ONLINE_STATUS 0
 #define DEFAULT_GATEWAYINTERFACE "br-lan"
 #define DEFAULT_GATEWAY_IPRANGE "0.0.0.0/0"
 #define DEFAULT_GATEWAYNAME "openNDS"
 #define DEFAULT_GATEWAYPORT 2050
 #define DEFAULT_GATEWAYFQDN "status.client"
 #define DEFAULT_STATUSPATH "/usr/lib/opennds/client_params.sh"
+#define DEFAULT_LOG_MOUNTPOINT "/tmp"
 #define DEFAULT_MAX_PAGE_SIZE 10240
 #define DEFAULT_FASPORT 0
 #define DEFAULT_LOGIN_OPTION_ENABLED 0
+#define DEFAULT_MAX_LOG_ENTRIES 100
 #define DEFAULT_USE_OUTDATED_MHD 0
 #define DEFAULT_ALLOW_PREEMPTIVE_AUTHENTICATION 0
 #define DEFAULT_UNESCAPE_CALLBACK_ENABLED 0
@@ -105,6 +108,7 @@ typedef enum {
 	TARGET_DROP,
 	TARGET_REJECT,
 	TARGET_ACCEPT,
+	TARGET_RETURN,
 	TARGET_LOG,
 	TARGET_ULOG
 } t_firewall_target;
@@ -177,10 +181,13 @@ typedef struct {
 	int daemon;					//@brief if daemon > 0, use daemon mode
 	int debuglevel;				//@brief Debug information verbosity
 	int maxclients;				//@brief Maximum number of clients allowed
+	int online_status;				//@brief Online status of the router, 1=online, 0=offline
 	char *gw_name;					//@brief Name of the gateway; e.g. its SSID or a unique identifier for use in a remote FAS
 	char *http_encoded_gw_name;			//@brief http encoded name of the gateway, used as a templated variable in splash.htm
 	char *url_encoded_gw_name;			//@brief url encoded name of the gateway used as variable in Preauth
 	char *gw_interface;				//@brief Interface we will manage
+	char *ext_interface;				//@brief Interface of this router which has the routed upstream connection
+	char *ext_gateway;				//@brief The IP address of the upstream gateway
 	char *gw_iprange;				//@brief IP range on gw_interface we will manage
 	char *gw_ip;					//@brief Internal IP (v4 or v6) for our web server
 	char *gw_address;				//@brief Internal IP with port for our web server
@@ -190,6 +197,7 @@ typedef struct {
 	unsigned int gw_port;				//@brief Port the webserver will run on
 	unsigned int fas_port;				//@brief Port the fas server will run on
 	int login_option_enabled;			//@brief Use default PreAuth Login script
+	unsigned long long int max_log_entries;	//@brief set the maximum number of log entries
 	int use_outdated_mhd;				//@brief Use outdated libmicrohttpd
 	unsigned long long int max_page_size;		//@brief Max page size to be served by libmicrohttpd
 	int allow_preemptive_authentication;		//@brief Allow Preemptive Authentication using the ndsctl utility
@@ -204,6 +212,7 @@ typedef struct {
 	char *fas_hid;					//@brief Hash provider for FAS
 	char *themespec_path;				//@brief Path to the ThemeSpec file to use for login_option_enabled = 3
 	char *tmpfsmountpoint;				//@brief Mountpoint of the tmpfs drive eg /tmp etc.
+	char *log_mountpoint;				//@brief Mountpoint of the log drive eg a USB drive mounted at /logs
 	char *webroot;					//@brief Directory containing splash pages, etc.
 	char *authdir;					//@brief Notional relative dir for authentication URL
 	char *denydir;					//@brief Notional relative dir for denial URL
